#
# spec file for package pbuilder
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2012 Frank Lichtenheld <frank@lichtenheld.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pbuilder
Version:        0.231
Release:        2.1
Summary:        Personal package builder for .deb packages
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
URL:            https://pbuilder-team.pages.debian.net/pbuilder
Source0:        http://deb.debian.org/debian/pool/main/p/pbuilder/pbuilder_%{version}.tar.xz
Patch0:         Makefile.patch
Patch1:         pdebuild-double-checkbuilddeps.patch
Patch2:         bash-completion-extglob.patch
Patch3:         pbuilder-ppc.patch
Requires:       debootstrap
Requires:       dpkg
Requires:       wget
%if 0%{?suse_version}
Recommends:     deb
Recommends:     fakeroot
Recommends:     sudo
%endif
BuildRequires:  dpkg
BuildRequires:  man
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
pbuilder constructs a chroot system, and builds a package inside the
chroot. It uses apt extensively, and a local mirror, or a fast
connection to a Debian/Ubuntu mirror is ideal, but not necessary.

"pbuilder create" uses debootstrap to create a chroot image.

"pbuilder update" updates the image to the current state of
testing/unstable/whatever

"pbuilder build" takes a *.dsc file and builds a binary in the chroot
image.

pdebuild is a wrapper for developers, to allow running pbuilder
just like "debuild", as a normal user.

%prep
%autosetup -p1

%build
%make_build

%install
%make_install

mkdir -p %{buildroot}/%{_defaultdocdir}
mv %{buildroot}/usr/share/doc/pbuilder %{buildroot}/%{_defaultdocdir}

for man in debuild-pbuilder.1 pbuilderrc.5 pbuilder.8 pdebuild.1; do
  category=${man: -1}
  install -D -m644 $man %{buildroot}%{_mandir}/man$category/$man
  gzip -9 %{buildroot}%{_mandir}/man$category/$man
done

for dir in build result aptcache ccache; do
  install -d %buildroot/var/cache/pbuilder/$dir
done

%check
%{__make} check

%files
%license COPYING AUTHORS
%doc ChangeLog README THANKS
%doc %{_defaultdocdir}/%{name}/examples
%dir    /etc/pbuilder
%config /etc/pbuilder/buildd-config.sh
%{_mandir}/man?/*
/usr/sbin/*
/usr/bin/*
/usr/lib/pbuilder
/usr/share/pbuilder
/var/cache/pbuilder
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Wed May  4 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.231
  * Set the debconf value for man-db/auto-update to false to save
    time in the package installing phase.
  * pdebuild: With --auto-debsign try to sign both _${arch}.changes
    and _source.changes if available.
  * buildpackage: Allow resolving the local hostname too.
  * bash-completion: Add --binary-indep to the completion.
  * pbuilderrc: Default to SOURCE_ONLY_CHANGES=yes.
  * satisfydepends-funcs: Fix parsing of build profiles when there
    is a << version restriction before the build profile marker.
  * autopkgtest:
  * Replace deprecated ADTTMP variable with AUTOPKGTEST_TMP.
  * Properly use of `tr` to lowercase strings.
  * Only delete the temporary directory when not running through
    autopkgtest.
  * Stop explicitly requiring the archive signing key, since that is very
    likely to already be installed anyway.
- Update to 0.230
  * createbuildenv:
  * Only try to print debootstrap.log if the file really exists.
  * Properly handle the case of a disabled internal cache.
  * Use packages from APTCACHE during debootstrap.
  * buildpackage-funcs: Fix whitespace handling in .dsc paths.
  * modules: Always call `systemctl stop` if using systemd's cgroups,
    preventing stray slices from being left behind.
  * buildpackage-funcs:
  * While setting up the cross-build env, only look at installed bin:gcc,
    not all available ones.
  * Print a useful error if GCC version detection fails.
  * Handle minor GCC versions and unversioned GCC dependencies.
  * checkparams: Use systemd-escape(1) to escape the package name
    in the slice name.
  * Add a --no-source-only-changes option to override a configured
    SOURCE_ONLY_CHANGES=yes.  Closes: #904716
  * Add more information in the slice name and scope description
    to ease the life of those running many pbuilder instances.
- Update to 0.229
  * pbuilder-modules: make bind mounts private on Linux.
  * modules: Support bind-mounting files.
  * satisfydepends-funcs:
  * Normalize restriction formulae.
  * Handle / separator for spaces from -classic.
  * createbuildenv:
  * Print a tail of debootstrap.log when debootstrap fails
  * buildpackage:
  * Ignore the R³ field if the installed dpkg is too old to appropriately
    deal with it.
  * Add support for Rules-Requires-Root.
    When R³:no fakeroot is not installed in the chroot.
- Drop bash-completion-have.patch, fixed upstream
- Drop pbuilderrc.patch, test-suite.patch
- Rebased bash-completion-extglob.patch, pbuilder-ppc.patch,
  pdebuild-double-checkbuilddeps.patch
* Sat Aug 23 2014 dvlaeev@suse.com
- Update pbuilder-ppc.patch to include ppc64el architecture
* Fri Apr  5 2013 frank.lichtenheld@sophos.com
- update to 0.215
  * Do not try to use /dev/shm if /run/shm is not present
  (deb#702811, deb#702102)
  * Add clang support hook script from Hideki Yamane (deb#700290)
* Fri Mar 29 2013 schwab@suse.de
- Add arm64 to pbuilder-apt-config to fix testsuite
* Sun Mar 10 2013 frank.lichtenheld@sophos.com
- update to 0.214
  * update documentation about CCACHEDIR (deb#694311)
  * added support for shared memory mounting point (deb#700591)
* Mon Nov  5 2012 frank.lichtenheld@sophos.com
- update to 0.213
  * set ccachedir to default to off. It's a minor optimization that a
  developer may choose to enable at the cost of incompatibility and some
  bugs. (deb#675691, deb#675843, deb#670651)
- set better project Url
* Thu Jul 19 2012 dvaleev@suse.com
- fix testsuite to run on ppc64
- add man to BuildRequires, testsuite requires it
* Wed May 30 2012 frank.lichtenheld@sophos.com
- update to 0.211
  * Test suite fixes, obsoletes parts of test-suite.patch
* Sun May 20 2012 frank.lichtenheld@sophos.com
- Replace BuildRequires on deb with dpkg
  * Only dpkg is really needed, and this makes it more
  portable (e.g. Fedora already contains dpkg)
* Sat May 19 2012 frank.lichtenheld@sophos.com
- Skip some pbuilder-apt-config tests on some arches
  * The checks do not take in account every possible
  build architecture.
* Sat May 12 2012 frank.lichtenheld@sophos.com
- Do not use extglob features in bash-completion.
  The bash in SLE 11 hasn't enabled it by default and
  can't even parse it if it isn't enabled globally.
- Enable test suite
* Thu May  3 2012 frank.lichtenheld@sophos.com
- Fix bash completion
* Thu May  3 2012 frank.lichtenheld@sophos.com
- Prepare for factory submission
  * Remove _service and add source file
  * Line-wrap description
* Sat Apr 28 2012 frank.lichtenheld@sophos.com
- make build on Fedora
* Tue Apr 10 2012 frank.lichtenheld@sophos.com
- update to 0.210
* Tue Mar 13 2012 frank.lichtenheld@sophos.com
- update to 0.208
* Sun Jan 29 2012 frank.lichtenheld@sophos.com
- update to 0.206
* Sat Dec 31 2011 frank.lichtenheld@sophos.com
- update to 0.205
* Tue Sep 20 2011 frank.lichtenheld@sophos.com
- update to 0.202
* Fri Aug 12 2011 flichtenheld@astaro.com
- update to 0.201
* Thu Jun  2 2011 flichtenheld@astaro.com
- update to 0.199+nmu4
* Sat Apr  9 2011 flichtenheld@astaro.com
- update to 0.199+nmu3
* Tue Feb 22 2011 flichtenheld@astaro.com
- update to 0.199+nmu2
* Wed Jan 26 2011 flichtenheld@astaro.com
- Initial packaging.
